import java.io.*;
import java.util.*;

public class divisors_dp_2 {
    BufferedReader br;
    StringTokenizer in;
    PrintWriter out;

    public String nextToken() throws IOException {
        while (in == null || !in.hasMoreTokens()) {
            in = new StringTokenizer(br.readLine());
        }
        return in.nextToken();
    }

    public int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    public double nextDouble() throws IOException {
        return Double.parseDouble(nextToken());
    }

    public long nextLong() throws IOException {
        return Long.parseLong(nextToken());
    }

    public static void main(String[] args) throws IOException {
        new divisors_dp_2().run();
    }

    final int maxPrimes = 1300;
    final int maxNum = 10000 + 100;
    final long mod = (long)1e9 + 7;

    class FenwickTree {
        int[] t;
        int n;

        FenwickTree() {
        }

        FenwickTree(int _n) {
            t = new int[_n + 1];
            n = _n;
        }

        void update(int v, int x) {
            for (int i = v + 1; i <= n; i += (i & (-i)))
                t[i] += x;
        }

        int get(int v) {
            int ans = 0;
            for (int i = v + 1; i > 0; i -= (i & (-i)))
                ans += t[i];
            return ans;
        }

        int get(int l, int r) {
            return get(r) - get(l - 1);
        }
    }

    int sizePrimes;
    int[] primes;
    int[] powers;
    int[] id;

    void factorize(int x) {
        sizePrimes = 0;
        for (int i = 2; i * i <= x; i++) {
            int power = 0;
            while (x % i == 0) {
                power++;
                x /= i;
            }
            if (power > 0) {
                primes[sizePrimes] = i;
                powers[sizePrimes++] = power;
            }
        }
        if (x > 1) {
            primes[sizePrimes] = x;
            powers[sizePrimes++] = 1;
        }
    }

    boolean isPrime(int x) {
        for (int i = 2; i * i <= x; i++)
            if (x % i == 0)
                return false;
        return true;
    }

    void precalcPrimePowers() {
        int primeNumber = 0;
        id = new int[maxNum];
        for (int i = 2; i <= maxNum; i++) {
            if (isPrime(i))
                id[i] = primeNumber++;
        }
    }

    public void solve() throws IOException {
        precalcPrimePowers();
        int n = nextInt();
        FenwickTree[] tree = new FenwickTree[maxPrimes];
        for (int i = 0; i < maxPrimes; i++)
            tree[i] = new FenwickTree(n);
        int[] as = new int[n];
        primes = new int[maxPrimes];
        powers = new int[maxPrimes];
        for (int i = 0; i < n; i++) {
            int x = nextInt();
            as[i] = x;
            factorize(x);
            for (int it = 0; it < sizePrimes; it++) {
                int prime = primes[it];
                int power = powers[it];
                tree[id[prime]].update(i, power);
            }
        }
        int q = nextInt();
        for (int it = 0; it < q; it++) {
            int type = nextInt();
            if (type == 0) {
                int pos = nextInt(), value = nextInt();
                --pos;
                factorize(as[pos]);
                for (int i = 0; i < sizePrimes; i++) {
                    int prime = primes[i];
                    int power = powers[i];
                    tree[id[prime]].update(pos, -power);
                }
                factorize(value);
                for (int i = 0; i < sizePrimes; i++) {
                    int prime = primes[i];
                    int power = powers[i];
                    tree[id[prime]].update(pos, power);
                }
                as[pos] = value;
            } else {
                int l = nextInt(), r = nextInt();
                --l;
                --r;

                long ans = 1;
                for (int i = 0; i < maxPrimes; i++)
                    ans = (ans * (tree[i].get(l, r) + 1)) % mod;
                out.println(ans);
            }
        }                                   
    }

    public void run() {
        try {
            br = new BufferedReader(new FileReader("divisors.in"));
            out = new PrintWriter("divisors.out"); 
            solve();

            out.close();
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(1);
        }
    }
}